@@ -3,7 +3,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2019 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2023 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -144,8 +144,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->do_rockridge= 1;
  m->do_iso1999= 0;
  m->ecma119_map= 1;
+ m->joliet_map= 1;
  m->do_aaip= 0;
- m->do_md5= 0;
+ m->do_md5= 64;
  m->no_emul_toc= 0;
  m->do_old_empty= 0;
  m->scdbackup_tag_name[0]= 0;
@@ -167,6 +168,10 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->do_follow_mount= 1;
  m->do_global_uid= 0;
  m->global_uid= 0;
+ m->isofs_size= 0;
+ m->isofs_has_what= 0;
+ m->tree_loaded= 0;
+ m->rr_loaded= 0;
  strcpy(m->volid, "ISOIMAGE");
  m->volid_default= 1;
  m->loaded_volid[0]= 0;
@@ -195,6 +200,15 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->zlib_level_default= m->zlib_level= 6;
  m->zisofs_block_size= m->zisofs_block_size_default= (1 << 15);
  m->zisofs_by_magic= 0;
+ m->zisofs_v2_enabled= 0;
+ m->zisofs_max_total_blocks= m->zisofs_max_total_blocks_default= 0x2000000;
+ m->zisofs_max_file_blocks= m->zisofs_max_file_blocks_default= 0x2000000;
+ m->zisofs_block_size= m->zisofs_block_size_default= (1 << 15);
+ m->zisofs_v2_block_size= m->zisofs_v2_block_size_default= (1 << 17);
+ m->zisofs_block_number_target= -1;
+ m->zisofs_bpt_discard_free_ratio= m->zisofs_bpt_discard_free_ratio_default=
+                                                                          -1.0;
+ m->zisofs_susp_z2= m->zisofs_susp_z2_default= 0;
  m->do_overwrite= 2;
  m->do_reassure= 0;
  m->drive_blacklist= NULL;
@@ -242,12 +256,16 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->auto_close= 0;
  m->write_speed= 0;  /* max */
  m->read_speed= -2;  /* do not set */
+ m->read_speed_force= 0;
+ m->read_speed_corr= 250000; /* look back at most 0.25 seconds with _force */
  m->fs= 4*512; /* 4 MiB */
  m->padding= 300*1024;
  m->do_padding_by_libisofs= 0;
  m->alignment= 0;
  m->do_stream_recording= 0;
  m->dvd_obs= 0;
+ m->do_obs_pad= 0;
+ m->bdr_obs_exempt= 0;
  m->modesty_on_drive= 0;
  m->min_buffer_usec= 5000;
  m->max_buffer_usec= 25000;
@@ -304,6 +322,8 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->iso_mbr_part_flag= 0;
  memset(m->gpt_guid, 0, 16);
  m->gpt_guid_mode= 0;
+ m->max_ce_entries= 31;             /* Linux hates >= RR_MAX_CE_ENTRIES = 32 */
+ m->max_ce_entries_flag= 2;        /* omit non-isofs fattr and ACL if needed */
  m->ascii_disc_label[0]= 0;
  m->grub2_sparc_core[0]= 0;
  memset(m->hfsp_serial_number, 0, 8);
@@ -462,6 +482,8 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->show_hfs_cmd_count= 0;
  m->show_hfs_cmds= NULL;
 
+ m->sparse_min_gap= 0;
+
  m->result_line[0]= 0;
  m->result_line_counter= 0;
  m->result_page_counter= 0;
