@@ -8,10 +8,11 @@
    or from xorriso/xorrecord.texi to xorriso/xorrecord.1.
    or from xorriso/xorriso-tcltk.texi to xorriso/xorriso-tcltk.1.
    or from xorriso/xorriso-dd-target.texi to xorriso/xorriso-dd-target.1.
+   of from test/merge_debian_iso.texi to test/merge_debian_iso.1
 
    The conversion rules are described at the beginning of xorriso/xorriso.texi
 
-   Copyright 2010 - 2019 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2010 - 2022 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 */
@@ -498,6 +499,9 @@ usage:;
    } else if(strcmp(argv[i], "-xorriso-dd-target") == 0) {
      strcpy(name_in, "xorriso-dd-target/xorriso-dd-target.texi");
      strcpy(name_out, "xorriso-dd-target/xorriso-dd-target.1");
+   } else if(strcmp(argv[i], "-merge_debian_isos") == 0) {
+     strcpy(name_in, "test/merge_debian_isos.texi");
+     strcpy(name_out, "test/merge_debian_isos.1");
    } else {
      fprintf(stderr, "%s : unknown option %s\n", argv[0], argv[i]);
      goto usage;
