@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2019 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2022 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -487,6 +487,25 @@ int Xorriso_option_assert_volid(struct XorrisO *xorriso, char *pattern,
 }
 
 
+/* Command -assess_indev_features */
+int Xorriso_option_assess_indev_features(struct XorrisO *xorriso, char *mode,
+                                         int flag)
+{
+ int ret;
+
+ if(strcmp(mode, "plain") != 0 && strcmp(mode, "cmd") != 0 &&
+    strcmp(mode, "as_mkisofs") != 0 && strcmp(mode, "replay") != 0 &&
+    mode[0] != 0) {
+   sprintf(xorriso->info_text, "-assess_indev_features: unknown mode '%s'",
+           mode);
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ ret= Xorriso_assess_written_features(xorriso, mode, 0);
+ return(ret);
+}
+
+
 /* Option -auto_charset "on"|"off" */
 int Xorriso_option_auto_charset(struct XorrisO *xorriso, char *mode, int flag)
 {
@@ -1357,8 +1376,35 @@ interval_text_long:;
      {ret= 0; goto ex;}
    }
 
- } else
+ } else if(strncmp(treatpt, "gpt_iso_bootable=", 17) == 0) {
+   if(strcmp(treatpt + 17, "off") == 0) {
+     xorriso->system_area_options&= ~(1 << 16);
+   } else if(strcmp(treatpt + 17, "on") == 0) {
+     xorriso->system_area_options|= (1 << 16);
+   } else {
+     sprintf(xorriso->info_text,
+             "-boot_image %s gpt_iso_bootable=: unknown mode : %s",
+             formpt, treatpt + 17);
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+     {ret= 0; goto ex;}
+   }
+
+ } else if(strncmp(treatpt, "gpt_iso_not_ro=", 15) == 0) {
+   if(strcmp(treatpt + 15, "off") == 0) {
+     xorriso->system_area_options&= ~(1 << 17);
+   } else if(strcmp(treatpt + 15, "on") == 0) {
+     xorriso->system_area_options|= (1 << 17);
+   } else {
+     sprintf(xorriso->info_text,
+             "-boot_image %s gpt_iso_not_ro=: unknown mode : %s",
+             formpt, treatpt + 15);
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+     {ret= 0; goto ex;}
+   }
+
+ } else {
    was_ok= 0;
+ }
 
  if(!was_ok) {
    sprintf(xorriso->info_text, "Unrecognized options with -boot_image: %s %s",
