@@ -2,7 +2,7 @@
 /* xorriso - libisoburn higher level API which creates, loads, manipulates
              and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2019 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2023 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -74,7 +74,7 @@ struct XorrisO;
 */
 #define Xorriso_header_version_majoR  1
 #define Xorriso_header_version_minoR  5
-#define Xorriso_header_version_micrO  2
+#define Xorriso_header_version_micrO  6
 
 
 /** If needed: Something like ".pl01" to indicate a bug fix. Normally empty.
@@ -207,8 +207,8 @@ int Xorriso_startup_libraries(struct XorrisO *xorriso, int flag);
          functions from the Command API.
 
          Wenn all desired activities are done, you may check whether there are
-         uncommited changes pending, compute an exit value, destroy the XorrisO
-         object, and exit your program.
+         uncommitted changes pending, compute an exit value, destroy the
+         XorrisO object, and exit your program.
 */
 
 
@@ -867,6 +867,9 @@ int Xorriso_sieve_dispose(struct XorrisO *xorriso, int flag);
                      argv[3]= Volume Id
     "Image size   :" up to 1 result from -print_size
                      argv[0]= number of blocks with "s" appended
+    "Indev feature:" up to 10000 results from -assess_indev_features plain
+                     argv[0]= name
+                     argv[1]= value
     "Jigdo files  :" up to 1 result from -list_extras
                      argv[0]= "yes" or "no"
     "Local ACL    :" up to 1 result from -list_extras
@@ -908,6 +911,9 @@ int Xorriso_sieve_dispose(struct XorrisO *xorriso, int flag);
     "Modif. Time  :" up to 1 result from -pvd_info
                      argv[0]= YYYYMMDDhhmmsscc
                      (Note: prefix is "Modif. Time  : ")
+    "Overburnt by :" up to 2 results from -toc
+                     argv[0]= number of readable blocks beyond ATIP leadout
+                     (Note: only reported with overburnt CD-RW)
     "PVD address  :" up to 1 result from -pvd_info
                      argv[0]= block address with "s" appended
     "Preparer Id  :" up to 1 result from -pvd_info
@@ -1290,6 +1296,11 @@ int Xorriso_option_as(struct XorrisO *xorriso, int argc, char **argv,
 int Xorriso_option_assert_volid(struct XorrisO *xorriso, char *pattern,
                                 char *severity, int flag);
 
+/* Command -assess_indev_features */
+/* @since 1.5.6 */
+int Xorriso_option_assess_indev_features(struct XorrisO *xorriso, char *mode,
+                                         int flag);
+
 /* Command -auto_charset "on"|"off" */
 /* @since 0.3.8 */
 int Xorriso_option_auto_charset(struct XorrisO *xorriso, char *mode, int flag);
@@ -1568,6 +1579,11 @@ int Xorriso_option_external_filter(struct XorrisO *xorriso,
 int Xorriso_option_extract(struct XorrisO *xorriso, char *disk_path,
                        char *iso_path, int flag);
 
+/* Command -extract_boot_images */
+/* @sice 1.5.4 */
+int Xorriso_option_extract_boot_images(struct XorrisO *xorriso,
+                                       char *disk_dir_path, int flag);
+
 /* Command -extract_cut */
 /* @since 0.2.6 */
 int Xorriso_option_extract_cut(struct XorrisO *xorriso, char *iso_rr_path,
@@ -1670,6 +1686,9 @@ int Xorriso_option_jigdo(struct XorrisO *xorriso, char *aspect, char *arg,
 /* @since 0.1.0 */
 int Xorriso_option_joliet(struct XorrisO *xorriso, char *mode, int flag);
 
+/* Command -joliet_map "unmapped" | "stripped" */
+int Xorriso_option_joliet_map(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Command -launch_frontend */
 /* @since 1.2.6 */
 int Xorriso_option_launch_frontend(struct XorrisO *xorriso,
@@ -2096,7 +2115,7 @@ int Xorriso_option_status_history_max(struct XorrisO *xorriso, int num1,
 
 /* Command -stdio_sync "on"|"off"|"end"|size */
 /* @since 0.4.6 */
-int Xorriso_option_stdio_sync(struct XorrisO *xorriso, char *rythm, int flag);
+int Xorriso_option_stdio_sync(struct XorrisO *xorriso, char *rhythm, int flag);
 
 /* Command -stream_recording */
 /* @since 0.1.8 */
@@ -2126,6 +2145,12 @@ int Xorriso_option_toc(struct XorrisO *xorriso, int flag);
 /* @since 1.2.6 */
 int Xorriso_option_toc_of(struct XorrisO *xorriso, char *which, int flag);
 
+/* Command -truncate_overwritable */
+/* @since 1.5.4 */
+int Xorriso_option_truncate_overwritable(struct XorrisO *xorriso,
+                                         char *adr_mode, char *adr_value,
+                                         char *adjust, int flag);
+
 /* Command -uid */
 /* @since 0.1.0 */
 int Xorriso_option_uid(struct XorrisO *xorriso, char *uid, int flag);
